pub const fn dsm_total_bytes(cluster: ClusterDim, per_block: u32) -> u64Expand description
Distributed-shared-memory helper: byte count needed to allocate
per_block bytes in every block of a cluster of size cluster.
pub const fn dsm_total_bytes(cluster: ClusterDim, per_block: u32) -> u64Distributed-shared-memory helper: byte count needed to allocate
per_block bytes in every block of a cluster of size cluster.